:mod:`connection` -- Connecting to MongoLab -- DEPRECATED
---------------------------------------------------------

.. automodule:: pymongolab.connection
    :synopsis: Connecting to MongoLab
    :members:
    :undoc-members:
    :show-inheritance:
